==> opennms-model-1.8.17-20120120.162530-45-sources.jar: org/opennms/netmgt/model/OnmsMapElementList.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
// OpenNMS Licensing       <license@opennms.org>
//     http://www.opennms.org/
//     http://www.opennms.com/
//
package org.opennms.netmgt.model;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import java.util.LinkedList;
import java.util.Collection;
import java.util.List;

/**
 * <p>OnmsMapElementList class.</p>
 *
 * @author ranger
 * @version $Id: $
 */
@XmlRootElement(name = "mapElements")
public class OnmsMapElementList extends LinkedList<OnmsMapElement> {
    private static final long serialVersionUID = 474241792322520294L;

    /**
     * <p>Constructor for OnmsMapElementList.</p>
     */
    public OnmsMapElementList() {
        super();
    }

    /**
     * <p>Constructor for OnmsMapElementList.</p>
     *
     * @param c a {@link java.util.Collection} object.
     */
    public OnmsMapElementList(Collection<? extends OnmsMapElement> c) {
        super(c);
    }

    /**
     * <p>getMapElements</p>
     *
     * @return a {@link java.util.List} object.
     */
    @XmlElement(name = "mapElement")
    public List<OnmsMapElement> getMapElements() {
        return this;
    }

    /**
     * <p>setMapElements</p>
     *
     * @param mapElements a {@link java.util.List} object.
     */
    public void setMapElements(List<OnmsMapElement> mapElements) {
        clear();
        addAll(mapElements);
    }
}

==> opennms-model-1.9.8-sources.jar: org/opennms/netmgt/model/OnmsMapElementList.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
// OpenNMS Licensing       <license@opennms.org>
//     http://www.opennms.org/
//     http://www.opennms.com/
//
package org.opennms.netmgt.model;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import java.util.LinkedList;
import java.util.Collection;
import java.util.List;

/**
 * <p>OnmsMapElementList class.</p>
 *
 * @author ranger
 * @version $Id: $
 */
@XmlRootElement(name = "mapElements")
public class OnmsMapElementList extends LinkedList<OnmsMapElement> {
    private static final long serialVersionUID = 474241792322520294L;

    /**
     * <p>Constructor for OnmsMapElementList.</p>
     */
    public OnmsMapElementList() {
        super();
    }

    /**
     * <p>Constructor for OnmsMapElementList.</p>
     *
     * @param c a {@link java.util.Collection} object.
     */
    public OnmsMapElementList(Collection<? extends OnmsMapElement> c) {
        super(c);
    }

    /**
     * <p>getMapElements</p>
     *
     * @return a {@link java.util.List} object.
     */
    @XmlElement(name = "mapElement")
    public List<OnmsMapElement> getMapElements() {
        return this;
    }

    /**
     * <p>setMapElements</p>
     *
     * @param mapElements a {@link java.util.List} object.
     */
    public void setMapElements(List<OnmsMapElement> mapElements) {
        clear();
        addAll(mapElements);
    }

    /**
     * <p>getCount</p>
     *
     * @return a {@link java.lang.Integer} object.
     */
    @XmlAttribute(name="count")
    public Integer getCount() {
        return this.size();
    }

}
